Package com.amazonaws.services.lambda.runtime.serialization.events.serializers
package com.amazonaws.services.lambda.runtime.serialization.events.serializers
-
ClassDescriptionInterface for event serializers that use org jsonSerializer for S3 event NOTE: Because the s3 event class provided by the SDK does not play well with Jackson through a class laoder, this class uses the low level org json library to serialize and deserialize the event.