Uses of Interface
com.amazonaws.services.lambda.runtime.serialization.util.Functions.R1
Packages that use Functions.R1
-
Uses of Functions.R1 in com.amazonaws.services.lambda.runtime.serialization.util
Methods in com.amazonaws.services.lambda.runtime.serialization.util that return Functions.R1Modifier and TypeMethodDescriptionstatic <A1,C, R> Functions.R1 <R, A1> ReflectUtil.bindInstanceR1(C instance, String name, boolean setAccessible, Class<? extends R> rType, Class<? super A1> a1Type) load an instance method that takes 1 parameter and returns type Rstatic <A1,C> Functions.R1 <C, A1> ReflectUtil.loadConstructor1(Class<? extends C> clazz, boolean setAccessible, Class<? super A1> a1Type) load constructor that takes 1 parameterstatic <C,R> Functions.R1 <R, C> ReflectUtil.loadInstanceR0(Class<? super C> clazz, String name, boolean setAccessible, Class<? extends R> rType) load instance method that takes no parameters and returns type Rstatic <A1,R> Functions.R1 <R, A1> ReflectUtil.loadStaticR1(Class<?> clazz, String name, boolean setAccessible, Class<? extends R> rType, Class<? super A1> a1Type) load static method that takes one parameter and returns type Rstatic <T> Functions.R1<T, Object> ReflectUtil.makeCaster(Class<? extends T> clazz) static Functions.R1<Object, Object> ReflectUtil.makeCaster(Type type)