Package com.amazonaws.services.lambda.runtime.serialization.util
package com.amazonaws.services.lambda.runtime.serialization.util
-
ClassDescriptionInterfaces for reflective function calls R functions return a type R with n number of arguments V functions are void A generics represent arguments for a function handleFunctions.R0<R>Functions.R1<R,
A1> Functions.R2<R,A1, A2> Functions.R3<R,A1, A2, A3> Functions.R4<R,A1, A2, A3, A4> Functions.R5<R,A1, A2, A3, A4, A5> Functions.R9<R,A1, A2, A3, A4, A5, A6, A7, A8, A9> Functions.V1<A1>Functions.V2<A1,A2> Class with reflection utilitiesClass with Utilities for serializing and deserializing customer classes